#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate-oauth
version:              1.7
visibility:           public
id:                   authenticate-oauth-1.7-3ng5pzoUfciBj1BbYhwJeJ
key:                  authenticate-oauth-1.7-3ng5pzoUfciBj1BbYhwJeJ
license:              BSD-3-Clause
maintainer:           Hiromi Ishii, Artem Chirkin
author:               Hiromi Ishii
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:
    Library to authenticate with OAuth for Haskell web applications.

description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.

category:             Web
abi:                  958673c4b8c89a2b47d958f777f4a3a9
exposed:              True
exposed-modules:      Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs:          /usr/lib/ghc-9.6.6/site-local/authenticate-oauth-1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/authenticate-oauth-1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/authenticate-oauth-1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate-oauth
hs-libraries:         HSauthenticate-oauth-1.7-3ng5pzoUfciBj1BbYhwJeJ
depends:
    RSA-2.4.1-EArwjJzbVN9HtnvXyige0N SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    base-4.18.2.1 base64-bytestring-1.2.1.0-Dq4HcYHUDsPZlT5wD319
    blaze-builder-0.4.4.1-6KOcxOg3SRMCcynO8y4gfB bytestring-0.11.5.3
    crypto-pubkey-types-0.4.3-7SJZFnr9Zv3EZkoPptR6Kl
    data-default-0.7.1.3-8w7fJ8RQ4j6IrMgdqaYpbC
    http-client-0.7.19-7POQGEcRJAHJFq20SO74PK
    http-types-0.12.4-J2e9o9UuDHFHkwukbbIWYx
    random-1.2.1.3-8xCOAhjQqZaHKyZvNvQjlZ time-1.12.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:
    /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock

haddock-html:         /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

